Stan Math Library: Member List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::op_matrix_vari Member List

This is the complete list of members for stan::math::op_matrix_vari, including all inherited members.

adj_ | stan::math::vari |
chain() | stan::math::vari | inlinevirtual
init_dependent() | stan::math::vari | inline
op_matrix_vari(double f, const Eigen::Matrix< stan::math::var, R, C > &vs) | stan::math::op_matrix_vari | inline
operator delete(void *) | stan::math::vari | inlinestatic
operator new(size_t nbytes) | stan::math::vari | inlinestatic
operator[](size_t n) const | stan::math::op_matrix_vari | inline
set_zero_adjoint() | stan::math::vari | inline
size() | stan::math::op_matrix_vari | inline
size_ | stan::math::op_matrix_vari | protected
val_ | stan::math::vari |
vari(const double x) | stan::math::vari | inlineexplicit
vari(const double x, bool stacked) | stan::math::vari | inline
vis_ | stan::math::op_matrix_vari | protected
~vari() | stan::math::vari | inlinevirtual

[ Stan Home Page ] © 2011–2016, Stan Development Team.